# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Illinois."""


ABINGDON_CITY = "00113"
ADAIR_CDP = "00178"
ADAMS_CDP = "00191"
ADDIEVILLE_VILLAGE = "00230"
ADDISON_VILLAGE = "00243"
ADELINE_VILLAGE = "00295"
ALBANY_VILLAGE = "00516"
ALBERS_VILLAGE = "00555"
ALBION_CITY = "00568"
ALDEN_CDP = "00594"
ALEDO_CITY = "00646"
ALEXANDER_CDP = "00659"
ALEXIS_VILLAGE = "00672"
ALGONQUIN_VILLAGE = "00685"
ALHAMBRA_VILLAGE = "00737"
ALLENDALE_VILLAGE = "00815"
ALLENVILLE_VILLAGE = "00867"
ALLERTON_VILLAGE = "00880"
ALMA_VILLAGE = "00919"
ALPHA_VILLAGE = "00971"
ALSEY_VILLAGE = "00997"
ALSIP_VILLAGE = "01010"
ALTAMONT_CITY = "01049"
ALTO_PASS_VILLAGE = "01205"
ALTON_CITY = "01114"
ALTONA_VILLAGE = "01140"
ALVAN_ALVIN_VILLAGE = "01242"
AMBOY_CITY = "01270"
ANCHOR_VILLAGE = "01361"
ANDALUSIA_VILLAGE = "01426"
ANDOVER_VILLAGE = "01491"
ANDRES_CDP = "01517"
ANNA_CITY = "01543"
ANNAPOLIS_CDP = "01556"
ANNAWAN_TOWN = "01569"
ANTIOCH_VILLAGE = "01595"
APPLE_CANYON_LAKE_CDP = "01647"
APPLE_RIVER_VILLAGE = "01673"
ARBURY_HILLS_CDP = "01803"
ARCOLA_CITY = "01881"
ARENZVILLE_VILLAGE = "01946"
ARGENTA_VILLAGE = "01972"
ARGYLE_CDP = "02050"
ARLINGTON_HEIGHTS_VILLAGE = "02154"
ARLINGTON_VILLAGE = "02102"
ARMINGTON_VILLAGE = "02206"
AROMA_PARK_VILLAGE = "02258"
ARROWSMITH_VILLAGE = "02342"
ARTHUR_VILLAGE = "02414"
ASHKUM_VILLAGE = "02479"
ASHLAND_VILLAGE = "02505"
ASHLEY_CITY = "02531"
ASHMORE_VILLAGE = "02557"
ASHTON_VILLAGE = "02583"
ASSUMPTION_CITY = "02609"
ASTORIA_TOWN = "02635"
ATHENS_CITY = "02674"
ATKINSON_TOWN = "02726"
ATLANTA_CITY = "02752"
ATWOOD_VILLAGE = "02882"
AUBURN_CITY = "02921"
AUGUSTA_VILLAGE = "02986"
AURORA_CITY = "03012"
AVA_CITY = "03103"
AVISTON_VILLAGE = "03181"
AVON_VILLAGE = "03207"
BAILEYVILLE_CDP = "03337"
BALDWIN_VILLAGE = "03454"
BANNER_VILLAGE = "03571"
BANNOCKBURN_VILLAGE = "03610"
BARDOLPH_VILLAGE = "03675"
BARRINGTON_HILLS_VILLAGE = "03883"
BARRINGTON_VILLAGE = "03844"
BARRY_CITY = "03948"
BARSTOW_CDP = "03987"
BARTELSO_VILLAGE = "04000"
BARTLETT_VILLAGE = "04013"
BARTONVILLE_VILLAGE = "04039"
BASCO_VILLAGE = "04052"
BATAVIA_CITY = "04078"
BATCHTOWN_VILLAGE = "04117"
BATH_VILLAGE = "04156"
BAY_VIEW_GARDENS_VILLAGE = "04273"
BAYLIS_VILLAGE = "04247"
BEACH_PARK_VILLAGE = "04303"
BEARDSTOWN_CITY = "04351"
BEASON_CDP = "04403"
BEAVERVILLE_VILLAGE = "04507"
BECKEMEYER_VILLAGE = "04533"
BEDFORD_PARK_VILLAGE = "04572"
BEECHER_CITY_VILLAGE = "04598"
BEECHER_VILLAGE = "04585"
BELGIUM_VILLAGE = "04689"
BELKNAP_VILLAGE = "04715"
BELLE_PRAIRIE_CITY_TOWN = "04793"
BELLE_RIVE_VILLAGE = "04806"
BELLEVILLE_CITY = "04845"
BELLEVUE_VILLAGE = "04871"
BELLFLOWER_VILLAGE = "04897"
BELLMONT_VILLAGE = "04936"
BELLWOOD_VILLAGE = "04975"
BELVIDERE_CITY = "05092"
BEMENT_VILLAGE = "05144"
BENLD_CITY = "05209"
BENSENVILLE_VILLAGE = "05248"
BENSON_VILLAGE = "05261"
BENTLEY_TOWN = "05274"
BENTON_CITY = "05300"
BERKELEY_VILLAGE = "05404"
BERLIN_VILLAGE = "05443"
BERWYN_CITY = "05573"
BETHALTO_VILLAGE = "05599"
BETHANY_VILLAGE = "05612"
BEVERLY_CDP = "05729"
BIG_FOOT_PRAIRIE_CDP = "05859"
BIG_ROCK_VILLAGE = "05976"
BIGGSVILLE_VILLAGE = "05898"
BINGHAM_VILLAGE = "06028"
BISHOP_HILL_VILLAGE = "06171"
BISMARCK_VILLAGE = "06184"
BLAIRSVILLE_CDP = "06444"
BLANDINSVILLE_VILLAGE = "06470"
BLOOMFIELD_CDP = "06565"
BLOOMINGDALE_VILLAGE = "06587"
BLOOMINGTON_CITY = "06613"
BLUE_ISLAND_CITY = "06704"
BLUE_MOUND_VILLAGE = "06756"
BLUFFS_VILLAGE = "06899"
BLUFORD_VILLAGE = "06964"
BOLINGBROOK_VILLAGE = "07133"
BONDVILLE_VILLAGE = "07211"
BONE_GAP_VILLAGE = "07224"
BONFIELD_VILLAGE = "07237"
BONNIE_BRAE_CDP = "07276"
BONNIE_VILLAGE = "07263"
BOODY_CDP = "07315"
BOULDER_HILL_CDP = "07419"
BOURBONNAIS_VILLAGE = "07471"
BOWEN_VILLAGE = "07510"
BRACEVILLE_VILLAGE = "07640"
BRADFORD_VILLAGE = "07692"
BRADLEY_VILLAGE = "07744"
BRAIDWOOD_CITY = "07770"
BREESE_CITY = "07913"
BRIDGEPORT_CITY = "08186"
BRIDGEVIEW_VILLAGE = "08225"
BRIGHTON_VILLAGE = "08264"
BRIMFIELD_VILLAGE = "08303"
BROADLANDS_VILLAGE = "08420"
BROADVIEW_VILLAGE = "08446"
BROADWELL_VILLAGE = "08472"
BROCTON_VILLAGE = "08524"
BROOKFIELD_VILLAGE = "08576"
BROOKLYN_VILLAGE = "08667"
BROOKPORT_CITY = "08706"
BROUGHTON_VILLAGE = "08875"
BROWNING_VILLAGE = "08953"
BROWNS_VILLAGE = "08979"
BROWNSTOWN_VILLAGE = "08992"
BRUSSELS_VILLAGE = "09148"
BRYANT_VILLAGE = "09161"
BUCKINGHAM_VILLAGE = "09304"
BUCKLEY_VILLAGE = "09317"
BUCKNER_VILLAGE = "09330"
BUDA_VILLAGE = "09356"
BUFFALO_GROVE_VILLAGE = "09447"
BUFFALO_PRAIRIE_CDP = "09499"
BUFFALO_VILLAGE = "09434"
BULL_VALLEY_VILLAGE = "09531"
BULPITT_VILLAGE = "09538"
BUNCOMBE_VILLAGE = "09551"
BUNKER_HILL_CITY = "09577"
BURBANK_CITY = "09642"
BUREAU_JUNCTION_VILLAGE = "09681"
BURLINGTON_VILLAGE = "09759"
BURNHAM_VILLAGE = "09798"
BURNT_PRAIRIE_VILLAGE = "09889"
BURR_RIDGE_VILLAGE = "09980"
BURTON_CDP = "10006"
BURTONS_BRIDGE_CDP = "10045"
BUSH_VILLAGE = "10084"
BUSHNELL_CITY = "10110"
BUTLER_VILLAGE = "10149"
BYRON_CITY = "10240"
CABERY_VILLAGE = "10292"
CABLE_CDP = "10305"
CAHOKIA_HEIGHTS_CITY = "10373"
CAIRO_CITY = "10383"
CALEDONIA_VILLAGE = "10422"
CALHOUN_VILLAGE = "10448"
CALUMET_CITY_CITY = "10487"
CALUMET_PARK_VILLAGE = "10513"
CAMARGO_VILLAGE = "10591"
CAMBRIA_VILLAGE = "10630"
CAMBRIDGE_VILLAGE = "10643"
CAMDEN_VILLAGE = "10695"
CAMERON_CDP = "10747"
CAMP_POINT_VILLAGE = "10877"
CAMPBELL_HILL_VILLAGE = "10773"
CAMPBELLS_ISLAND_CDP = "10786"
CAMPTON_HILLS_VILLAGE = "10906"
CAMPUS_VILLAGE = "10916"
CANDLEWICK_LAKE_CDP = "10936"
CANTON_CITY = "11007"
CANTRALL_VILLAGE = "11033"
CAPRON_VILLAGE = "11124"
CARBON_CLIFF_VILLAGE = "11150"
CARBON_HILL_VILLAGE = "11176"
CARBONDALE_CITY = "11163"
CARLINVILLE_CITY = "11202"
CARLOCK_VILLAGE = "11215"
CARLYLE_CITY = "11228"
CARMAN_CDP = "11267"
CARMI_CITY = "11293"
CAROL_STREAM_VILLAGE = "11332"
CARPENTERSVILLE_VILLAGE = "11358"
CARRIER_MILLS_VILLAGE = "11397"
CARROLLTON_CITY = "11462"
CARTERVILLE_CITY = "11514"
CARTHAGE_CITY = "11527"
CARY_VILLAGE = "11592"
CASEY_CITY = "11618"
CASEYVILLE_VILLAGE = "11644"
CATLIN_VILLAGE = "11774"
CAVE_IN_ROCK_VILLAGE = "11826"
CEDAR_POINT_VILLAGE = "11982"
CEDARVILLE_VILLAGE = "12008"
CENTRAL_CITY_VILLAGE = "12151"
CENTRALIA_CITY = "12164"
CERRO_GORDO_VILLAGE = "12268"
CHADWICK_VILLAGE = "12294"
CHAMPAIGN_CITY = "12385"
CHANDLERVILLE_VILLAGE = "12450"
CHANNAHON_VILLAGE = "12476"
CHANNEL_LAKE_CDP = "12489"
CHAPIN_VILLAGE = "12528"
CHARLESTON_CITY = "12567"
CHATHAM_VILLAGE = "12684"
CHATSWORTH_TOWN = "12710"
CHEBANSE_VILLAGE = "12801"
CHEMUNG_CDP = "12879"
CHENOA_CITY = "12931"
CHERRY_VALLEY_VILLAGE = "13074"
CHERRY_VILLAGE = "12970"
CHESTER_CITY = "13139"
CHESTERFIELD_VILLAGE = "13165"
CHESTNUT_CDP = "13230"
CHICAGO_HEIGHTS_CITY = "14026"
CHICAGO_RIDGE_VILLAGE = "14065"
CHICAGO_CITY = "14000"
CHILLICOTHE_CITY = "14117"
CHRISMAN_CITY = "14273"
CHRISTOPHER_CITY = "14286"
CICERO_TOWN = "14351"
CISCO_VILLAGE = "14442"
CISNE_VILLAGE = "14455"
CISSNA_PARK_VILLAGE = "14468"
CLAREMONT_VILLAGE = "14533"
CLARENDON_HILLS_VILLAGE = "14572"
CLAY_CITY_VILLAGE = "14715"
CLAYTON_VILLAGE = "14767"
CLEAR_LAKE_VILLAGE = "14845"
CLEVELAND_VILLAGE = "14923"
CLIFTON_VILLAGE = "14936"
CLINTON_CITY = "15001"
COAL_CITY_VILLAGE = "15170"
COAL_VALLEY_VILLAGE = "15235"
COALTON_VILLAGE = "15209"
COATSBURG_VILLAGE = "15261"
COBDEN_VILLAGE = "15300"
COFFEEN_CITY = "15352"
COLCHESTER_CITY = "15378"
COLETA_VILLAGE = "15469"
COLFAX_VILLAGE = "15495"
COLLINSVILLE_CITY = "15599"
COLONA_CITY = "15664"
COLP_VILLAGE = "15807"
COLUMBIA_CITY = "15833"
COLUMBUS_VILLAGE = "15846"
COMO_CDP = "15950"
COMPTON_VILLAGE = "15989"
CONCORD_VILLAGE = "16054"
CONGERVILLE_VILLAGE = "16119"
COOKSVILLE_VILLAGE = "16210"
CORAL_CDP = "16301"
CORDOVA_VILLAGE = "16366"
CORNELL_VILLAGE = "16405"
CORNLAND_CDP = "16431"
CORTLAND_TOWN = "16470"
COULTERVILLE_VILLAGE = "16613"
COUNTRY_CLUB_HILLS_CITY = "16691"
COUNTRYSIDE_CITY = "16873"
COWDEN_VILLAGE = "17055"
COYNE_CENTER_CDP = "17077"
CRAB_ORCHARD_CDP = "17094"
CRAINVILLE_VILLAGE = "17185"
CREAL_SPRINGS_CITY = "17289"
CRESCENT_CITY_VILLAGE = "17406"
CREST_HILL_CITY = "17458"
CRESTON_VILLAGE = "17471"
CRESTWOOD_VILLAGE = "17497"
CRETE_VILLAGE = "17523"
CREVE_COEUR_VILLAGE = "17549"
CROSSVILLE_VILLAGE = "17783"
CRYSTAL_LAKE_CITY = "17887"
CRYSTAL_LAWNS_CDP = "17939"
CUBA_CITY = "17991"
CULLOM_VILLAGE = "18030"
CURRAN_VILLAGE = "18147"
CUSTER_PARK_CDP = "18212"
CUTLER_VILLAGE = "18225"
CYPRESS_VILLAGE = "18251"
DAHLGREN_VILLAGE = "18303"
DAKOTA_VILLAGE = "18342"
DALLAS_CITY_CITY = "18420"
DALTON_CITY_VILLAGE = "18446"
DALZELL_VILLAGE = "18459"
DAMIANSVILLE_VILLAGE = "18472"
DANA_VILLAGE = "18485"
DANFORTH_VILLAGE = "18498"
DANVERS_VILLAGE = "18537"
DANVILLE_CITY = "18563"
DARIEN_CITY = "18628"
DARMSTADT_CDP = "18641"
DAVIS_JUNCTION_VILLAGE = "18719"
DAVIS_VILLAGE = "18706"
DAWSON_VILLAGE = "18745"
DAYTON_CDP = "18771"
DE_LAND_VILLAGE = "19200"
DE_PUE_VILLAGE = "19499"
DE_SOTO_VILLAGE = "19616"
DE_WITT_VILLAGE = "19798"
DEKALB_CITY = "19161"
DECATUR_CITY = "18823"
DEER_CREEK_VILLAGE = "18940"
DEER_GROVE_VILLAGE = "19031"
DEER_PARK_VILLAGE = "19083"
DEERFIELD_VILLAGE = "18992"
DELAVAN_CITY = "19226"
DES_PLAINES_CITY = "19642"
DETROIT_VILLAGE = "19681"
DEWEY_CDP = "19746"
DIAMOND_VILLAGE = "19837"
DIETERICH_VILLAGE = "19915"
DIVERNON_VILLAGE = "20045"
DIX_VILLAGE = "20123"
DIXMOOR_VILLAGE = "20149"
DIXON_CITY = "20162"
DOLTON_VILLAGE = "20292"
DONGOLA_VILLAGE = "20305"
DONNELLSON_VILLAGE = "20318"
DONOVAN_VILLAGE = "20331"
DORCHESTER_VILLAGE = "20370"
DOVER_VILLAGE = "20526"
DOWELL_VILLAGE = "20565"
DOWNERS_GROVE_VILLAGE = "20591"
DOWNS_VILLAGE = "20643"
DU_BOIS_VILLAGE = "20890"
DU_QUOIN_CITY = "21267"
DUNDAS_CDP = "21020"
DUNFERMLINE_VILLAGE = "21098"
DUNLAP_VILLAGE = "21176"
DUPO_VILLAGE = "21254"
DURAND_VILLAGE = "21280"
DWIGHT_VILLAGE = "21358"
EAGARVILLE_VILLAGE = "21410"
EAGLE_LAKE_CDP = "21475"
EARLVILLE_CITY = "21540"
EAST_ALTON_VILLAGE = "21553"
EAST_BROOKLYN_VILLAGE = "21579"
EAST_CAPE_GIRARDEAU_VILLAGE = "21605"
EAST_CARONDELET_VILLAGE = "21618"
EAST_DUBUQUE_CITY = "21683"
EAST_DUNDEE_VILLAGE = "21696"
EAST_GALESBURG_VILLAGE = "21826"
EAST_GILLESPIE_VILLAGE = "21852"
EAST_HAZEL_CREST_VILLAGE = "21904"
EAST_LYNN_CDP = "22021"
EAST_MOLINE_CITY = "22073"
EAST_PEORIA_CITY = "22164"
EAST_ST_LOUIS_CITY = "22255"
EASTON_VILLAGE = "22151"
EDDYVILLE_VILLAGE = "22398"
EDGEWOOD_VILLAGE = "22567"
EDGINGTON_CDP = "22619"
EDINBURG_VILLAGE = "22645"
EDWARDSVILLE_CITY = "22697"
EFFINGHAM_CITY = "22736"
EL_DARA_VILLAGE = "22957"
EL_PASO_CITY = "23737"
ELBURN_VILLAGE = "22931"
ELDORADO_CITY = "23009"
ELDRED_VILLAGE = "23022"
ELGIN_CITY = "23074"
ELIZA_CDP = "23139"
ELIZABETH_VILLAGE = "23165"
ELIZABETHTOWN_VILLAGE = "23191"
ELK_GROVE_VILLAGE_VILLAGE = "23256"
ELKHART_VILLAGE = "23269"
ELKVILLE_VILLAGE = "23373"
ELLIOTT_VILLAGE = "23425"
ELLIS_GROVE_VILLAGE = "23503"
ELLISVILLE_VILLAGE = "23529"
ELLSWORTH_VILLAGE = "23555"
ELMHURST_CITY = "23620"
ELMWOOD_PARK_VILLAGE = "23724"
ELMWOOD_CITY = "23698"
ELSAH_VILLAGE = "23776"
ELVASTON_VILLAGE = "23841"
ELWIN_CDP = "23919"
ELWOOD_VILLAGE = "23945"
EMDEN_VILLAGE = "23971"
EMINGTON_VILLAGE = "24062"
ENERGY_VILLAGE = "24166"
ENFIELD_VILLAGE = "24179"
EQUALITY_VILLAGE = "24348"
ERIE_VILLAGE = "24374"
ESSEX_VILLAGE = "24452"
EUREKA_CITY = "24543"
EVANSTON_CITY = "24582"
EVANSVILLE_VILLAGE = "24608"
EVERGREEN_PARK_VILLAGE = "24634"
EWING_VILLAGE = "24673"
EXETER_VILLAGE = "24699"
FAIRBURY_CITY = "24764"
FAIRFIELD_CITY = "24816"
FAIRMONT_CDP = "24920"
FAIRMONT_CITY_VILLAGE = "24933"
FAIRMOUNT_VILLAGE = "24985"
FAIRVIEW_HEIGHTS_CITY = "25141"
FAIRVIEW_VILLAGE = "25063"
FALL_CREEK_CDP = "25245"
FARINA_VILLAGE = "25375"
FARMER_CITY_CITY = "25414"
FARMERSVILLE_VILLAGE = "25440"
FARMINGTON_CITY = "25531"
FAYETTEVILLE_VILLAGE = "25713"
FERRIS_VILLAGE = "25895"
FIDELITY_VILLAGE = "25960"
FIELDON_VILLAGE = "26012"
FILLMORE_VILLAGE = "26077"
FINDLAY_VILLAGE = "26116"
FISHER_VILLAGE = "26194"
FITHIAN_VILLAGE = "26233"
FLANAGAN_VILLAGE = "26311"
FLAT_ROCK_VILLAGE = "26350"
FLORA_CITY = "26454"
FLORAVILLE_CDP = "26467"
FLORENCE_VILLAGE = "26480"
FLOSSMOOR_VILLAGE = "26571"
FOOSLAND_VILLAGE = "26662"
FORD_HEIGHTS_VILLAGE = "26710"
FOREST_CITY_VILLAGE = "26753"
FOREST_LAKE_CDP = "26896"
FOREST_PARK_VILLAGE = "26935"
FOREST_VIEW_VILLAGE = "26987"
FORREST_VILLAGE = "27026"
FORRESTON_VILLAGE = "27065"
FORSYTH_VILLAGE = "27091"
FOWLER_CDP = "27377"
FOX_LAKE_HILLS_CDP = "27455"
FOX_LAKE_VILLAGE = "27442"
FOX_RIVER_GROVE_VILLAGE = "27533"
FRANKFORT_SQUARE_CDP = "27644"
FRANKFORT_VILLAGE = "27624"
FRANKLIN_GROVE_VILLAGE = "27689"
FRANKLIN_PARK_VILLAGE = "27702"
FRANKLIN_VILLAGE = "27663"
FRANKLINVILLE_CDP = "27728"
FREEBURG_VILLAGE = "27806"
FREEMAN_SPUR_VILLAGE = "27858"
FREEPORT_CITY = "27884"
FULTON_CITY = "28144"
FULTS_VILLAGE = "28170"
GAGES_LAKE_CDP = "28248"
GALATIA_VILLAGE = "28261"
GALENA_CITY = "28300"
GALESBURG_CITY = "28326"
GALT_CDP = "28404"
GALVA_CITY = "28430"
GARDEN_PRAIRIE_CDP = "28612"
GARDNER_VILLAGE = "28638"
GARRETT_VILLAGE = "28742"
GAYS_VILLAGE = "28807"
GENESEO_CITY = "28846"
GENEVA_CITY = "28872"
GENOA_CITY = "28898"
GEORGETOWN_CDP = "28950"
GEORGETOWN_CITY = "28963"
GERMAN_VALLEY_VILLAGE = "29093"
GERMANTOWN_HILLS_VILLAGE = "29080"
GERMANTOWN_VILLAGE = "29041"
GIBSON_CITY_CITY = "29125"
GIFFORD_VILLAGE = "29145"
GILBERTS_VILLAGE = "29171"
GILLESPIE_CITY = "29236"
GILMAN_CITY = "29275"
GILSON_CDP = "29340"
GIRARD_CITY = "29392"
GLADSTONE_VILLAGE = "29431"
GLASFORD_VILLAGE = "29483"
GLASGOW_VILLAGE = "29496"
GLEN_CARBON_VILLAGE = "29639"
GLEN_ELLYN_VILLAGE = "29756"
GLENCOE_VILLAGE = "29652"
GLENDALE_HEIGHTS_VILLAGE = "29730"
GLENVIEW_VILLAGE = "29938"
GLENWOOD_VILLAGE = "30029"
GODFREY_VILLAGE = "30094"
GODLEY_VILLAGE = "30120"
GOLCONDA_CITY = "30133"
GOLDEN_GATE_VILLAGE = "30250"
GOLDEN_VILLAGE = "30159"
GOLF_VILLAGE = "30328"
GOOD_HOPE_VILLAGE = "30458"
GOODENOW_CDP = "30419"
GOODFIELD_VILLAGE = "30445"
GOOFY_RIDGE_CDP = "30510"
GOREVILLE_VILLAGE = "30575"
GORHAM_VILLAGE = "30588"
GRAFTON_CITY = "30653"
GRAND_DETOUR_CDP = "30705"
GRAND_RIDGE_VILLAGE = "30757"
GRAND_TOWER_CITY = "30770"
GRANDVIEW_VILLAGE = "30835"
GRANDWOOD_PARK_CDP = "30900"
GRANITE_CITY_CITY = "30926"
GRANT_PARK_VILLAGE = "30991"
GRANTFORK_VILLAGE = "30978"
GRANVILLE_VILLAGE = "31017"
GRAYSLAKE_VILLAGE = "31121"
GRAYVILLE_CITY = "31165"
GREEN_OAKS_VILLAGE = "31446"
GREEN_VALLEY_VILLAGE = "31563"
GREENFIELD_CITY = "31368"
GREENUP_VILLAGE = "31524"
GREENVIEW_VILLAGE = "31576"
GREENVILLE_CITY = "31589"
GREENWOOD_VILLAGE = "31667"
GRIDLEY_VILLAGE = "31732"
GRIGGSVILLE_CITY = "31771"
GULFPORT_VILLAGE = "31991"
GURNEE_VILLAGE = "32018"
HAINESVILLE_VILLAGE = "32200"
HAMBURG_VILLAGE = "32395"
HAMEL_VILLAGE = "32408"
HAMILTON_CITY = "32434"
HAMLET_CDP = "32473"
HAMMOND_VILLAGE = "32499"
HAMPSHIRE_VILLAGE = "32525"
HAMPTON_VILLAGE = "32564"
HANAFORD_VILLAGE = "32616"
HANNA_CITY_VILLAGE = "32668"
HANOVER_PARK_VILLAGE = "32746"
HANOVER_VILLAGE = "32707"
HARDIN_VILLAGE = "32850"
HARDING_CDP = "32876"
HARMON_VILLAGE = "32967"
HARMONY_CDP = "33019"
HARRISBURG_CITY = "33136"
HARRISON_CDP = "33162"
HARRISTOWN_VILLAGE = "33227"
HARTFORD_VILLAGE = "33279"
HARTLAND_CDP = "33292"
HARTSBURG_VILLAGE = "33318"
HARVARD_CITY = "33331"
HARVEL_VILLAGE = "33357"
HARVEY_CITY = "33383"
HARWOOD_HEIGHTS_VILLAGE = "33435"
HAVANA_CITY = "33513"
HAWTHORN_WOODS_VILLAGE = "33630"
HAZEL_CREST_VILLAGE = "33695"
HEBRON_VILLAGE = "33851"
HECKER_VILLAGE = "33877"
HENDERSON_VILLAGE = "34007"
HENNEPIN_VILLAGE = "34098"
HENNING_VILLAGE = "34137"
HENRY_CITY = "34163"
HERITAGE_LAKE_CDP = "34272"
HERRICK_VILLAGE = "34332"
HERRIN_CITY = "34358"
HERSCHER_VILLAGE = "34384"
HETTICK_VILLAGE = "34423"
HEYWORTH_VILLAGE = "34449"
HICKORY_HILLS_CITY = "34514"
HIDALGO_VILLAGE = "34553"
HIGHLAND_PARK_CITY = "34722"
HIGHLAND_CITY = "34670"
HIGHWOOD_CITY = "34865"
HILLCREST_VILLAGE = "34982"
HILLSBORO_CITY = "35047"
HILLSDALE_VILLAGE = "35073"
HILLSIDE_VILLAGE = "35086"
HILLVIEW_VILLAGE = "35203"
HINCKLEY_VILLAGE = "35268"
HINDSBORO_VILLAGE = "35281"
HINSDALE_VILLAGE = "35307"
HODGKINS_VILLAGE = "35385"
HOFFMAN_ESTATES_VILLAGE = "35411"
HOFFMAN_VILLAGE = "35398"
HOLCOMB_CDP = "35463"
HOLIDAY_HILLS_VILLAGE = "35515"
HOLIDAY_SHORES_CDP = "35541"
HOLLOWAYVILLE_VILLAGE = "35671"
HOMER_GLEN_VILLAGE = "35835"
HOMER_VILLAGE = "35814"
HOMETOWN_CITY = "35866"
HOMEWOOD_VILLAGE = "35879"
HOOPESTON_CITY = "36061"
HOOPPOLE_VILLAGE = "36074"
HOPEDALE_VILLAGE = "36126"
HOPEWELL_VILLAGE = "36150"
HOPKINS_PARK_VILLAGE = "36190"
HOYLETON_VILLAGE = "36347"
HUDSON_VILLAGE = "36438"
HUEY_VILLAGE = "36477"
HULL_VILLAGE = "36516"
HUMBOLDT_VILLAGE = "36542"
HUME_VILLAGE = "36568"
HUNTLEY_VILLAGE = "36750"
HURST_CITY = "36815"
HUTSONVILLE_VILLAGE = "36841"
ILLINOIS_CITY_CDP = "37062"
ILLIOPOLIS_VILLAGE = "37127"
INA_VILLAGE = "37179"
INDIAN_CREEK_VILLAGE = "37218"
INDIAN_HEAD_PARK_VILLAGE = "37257"
INDIANOLA_VILLAGE = "37348"
INDUSTRY_VILLAGE = "37439"
INGALLS_PARK_CDP = "37465"
INVERNESS_VILLAGE = "37608"
IOLA_VILLAGE = "37621"
IPAVA_VILLAGE = "37647"
IROQUOIS_VILLAGE = "37712"
IRVING_VILLAGE = "37738"
IRVINGTON_VILLAGE = "37777"
IRWIN_VILLAGE = "37803"
ISLAND_LAKE_VILLAGE = "37894"
ITASCA_VILLAGE = "37907"
IUKA_VILLAGE = "37933"
IVESDALE_VILLAGE = "37998"
JACKSONVILLE_CITY = "38115"
JANESVILLE_CDP = "38232"
JEFFERSONVILLE_VILLAGE = "38323"
JEISYVILLE_VILLAGE = "38349"
JEROME_VILLAGE = "38375"
JERSEYVILLE_CITY = "38414"
JEWETT_VILLAGE = "38427"
JOHNSBURG_VILLAGE = "38479"
JOHNSONVILLE_VILLAGE = "38531"
JOHNSTON_CITY_CITY = "38544"
JOLIET_CITY = "38570"
JONESBORO_CITY = "38635"
JOPPA_VILLAGE = "38674"
JOSLIN_CDP = "38726"
JOY_VILLAGE = "38739"
JUNCTION_CITY_VILLAGE = "38791"
JUNCTION_VILLAGE = "38778"
JUSTICE_VILLAGE = "38830"
KAMPSVILLE_VILLAGE = "38856"
KANE_VILLAGE = "38869"
KANEVILLE_VILLAGE = "38895"
KANGLEY_VILLAGE = "38921"
KANKAKEE_CITY = "38934"
KANSAS_VILLAGE = "38986"
KAPPA_VILLAGE = "39038"
KARNAK_VILLAGE = "39077"
KASKASKIA_VILLAGE = "39129"
KEENES_VILLAGE = "39233"
KEENSBURG_VILLAGE = "39259"
KEITHSBURG_CITY = "39298"
KELL_VILLAGE = "39324"
KEMPTON_VILLAGE = "39441"
KENILWORTH_VILLAGE = "39519"
KENNEY_VILLAGE = "39532"
KEWANEE_CITY = "39727"
KEYESPORT_VILLAGE = "39753"
KILBOURNE_VILLAGE = "39857"
KILDEER_VILLAGE = "39883"
KINCAID_VILLAGE = "39909"
KINDERHOOK_VILLAGE = "39922"
KINGS_CDP = "39987"
KINGSTON_CDP = "40052"
KINGSTON_MINES_VILLAGE = "40091"
KINGSTON_VILLAGE = "40065"
KINMUNDY_CITY = "40117"
KINSMAN_VILLAGE = "40143"
KIRKLAND_VILLAGE = "40156"
KIRKWOOD_VILLAGE = "40182"
KNOLLWOOD_CDP = "40364"
KNOXVILLE_CITY = "40416"
LA_CLEDE_CDP = "40520"
LA_FAYETTE_VILLAGE = "40676"
LA_GRANGE_PARK_VILLAGE = "40793"
LA_GRANGE_VILLAGE = "40767"
LA_HARPE_CITY = "40832"
LA_MOILLE_VILLAGE = "41794"
LA_PRAIRIE_VILLAGE = "42080"
LA_ROSE_VILLAGE = "42171"
LAPLACE_CDP = "42067"
LASALLE_CITY = "42184"
LACON_CITY = "40559"
LADD_VILLAGE = "40598"
LAKE_BARRINGTON_VILLAGE = "40884"
LAKE_BLUFF_VILLAGE = "40910"
LAKE_CAMELOT_CDP = "40962"
LAKE_CARROLL_CDP = "40980"
LAKE_CATHERINE_CDP = "40988"
LAKE_CITY_CDP = "41040"
LAKE_FOREST_CITY = "41105"
LAKE_HOLIDAY_CDP = "41157"
LAKE_KA_HO_VILLAGE = "41214"
LAKE_PETERSBURG_CDP = "41404"
LAKE_SUMMERSET_CDP = "41456"
LAKE_VILLA_VILLAGE = "41586"
LAKE_ZURICH_VILLAGE = "41742"
LAKE_IN_THE_HILLS_VILLAGE = "41183"
LAKE_OF_THE_WOODS_CDP = "41346"
LAKEMOOR_VILLAGE = "41326"
LAKEWOOD_CDP = "41677"
LAKEWOOD_SHORES_CDP = "41716"
LAKEWOOD_VILLAGE = "41651"
LANARK_CITY = "41859"
LANE_CDP = "41950"
LANGLEYVILLE_CDP = "42002"
LANSING_VILLAGE = "42028"
LATHAM_VILLAGE = "42249"
LAWRENCE_CDP = "42392"
LAWRENCEVILLE_CITY = "42405"
LE_ROY_CITY = "42971"
LEAF_RIVER_VILLAGE = "42457"
LEBANON_CITY = "42496"
LEE_CENTER_CDP = "42600"
LEE_VILLAGE = "42587"
LELAND_GROVE_CITY = "42769"
LELAND_VILLAGE = "42756"
LEMONT_VILLAGE = "42795"
LENA_VILLAGE = "42834"
LENZBURG_VILLAGE = "42860"
LEONORE_VILLAGE = "42912"
LERNA_VILLAGE = "42938"
LEWISTOWN_CITY = "43055"
LEXINGTON_CITY = "43094"
LIBERTY_VILLAGE = "43133"
LIBERTYVILLE_VILLAGE = "43250"
LILY_LAKE_VILLAGE = "43406"
LIMA_VILLAGE = "43445"
LIMESTONE_VILLAGE = "43510"
LINCOLN_CITY = "43536"
LINCOLNSHIRE_VILLAGE = "43666"
LINCOLNWOOD_VILLAGE = "43744"
LINDENHURST_VILLAGE = "43770"
LISBON_VILLAGE = "43900"
LISLE_VILLAGE = "43939"
LITCHFIELD_CITY = "43965"
LITERBERRY_CDP = "43978"
LITTLE_YORK_VILLAGE = "44082"
LITTLETON_VILLAGE = "44056"
LIVERPOOL_VILLAGE = "44121"
LIVINGSTON_VILLAGE = "44160"
LOAMI_VILLAGE = "44173"
LOCKPORT_HEIGHTS_CDP = "44244"
LOCKPORT_CITY = "44225"
LODA_VILLAGE = "44264"
LOMAX_VILLAGE = "44381"
LOMBARD_VILLAGE = "44407"
LONDON_MILLS_VILLAGE = "44446"
LONG_CREEK_VILLAGE = "44498"
LONG_GROVE_VILLAGE = "44524"
LONG_LAKE_CDP = "44550"
LONG_POINT_VILLAGE = "44576"
LONGVIEW_VILLAGE = "44602"
LORAINE_VILLAGE = "44719"
LORENZO_CDP = "44784"
LOST_NATION_CDP = "44836"
LOSTANT_VILLAGE = "44823"
LOUISVILLE_VILLAGE = "44927"
LOVES_PARK_CITY = "45031"
LOVINGTON_VILLAGE = "45044"
LOWPOINT_CDP = "45109"
LUDLOW_VILLAGE = "45174"
LYNDON_VILLAGE = "45278"
LYNN_CENTER_CDP = "45343"
LYNNVILLE_VILLAGE = "45369"
LYNWOOD_VILLAGE = "45421"
LYONS_VILLAGE = "45434"
MACEDONIA_VILLAGE = "45642"
MACHESNEY_PARK_VILLAGE = "45726"
MACKINAW_VILLAGE = "45785"
MACOMB_CITY = "45889"
MACON_CITY = "45941"
MADISON_CITY = "45993"
MAEYSTOWN_VILLAGE = "46058"
MAGNOLIA_VILLAGE = "46110"
MAHOMET_VILLAGE = "46136"
MAKANDA_VILLAGE = "46214"
MALDEN_VILLAGE = "46240"
MALTA_VILLAGE = "46279"
MANCHESTER_VILLAGE = "46331"
MANHATTAN_VILLAGE = "46357"
MANITO_VILLAGE = "46383"
MANLIUS_VILLAGE = "46422"
MANSFIELD_VILLAGE = "46487"
MANTENO_VILLAGE = "46500"
MAPLE_PARK_VILLAGE = "46604"
MAPLETON_VILLAGE = "46643"
MAQUON_VILLAGE = "46695"
MARCELLINE_CDP = "46734"
MARENGO_CITY = "46786"
MARIETTA_VILLAGE = "46825"
MARINE_VILLAGE = "46864"
MARION_CITY = "46916"
MARISSA_VILLAGE = "46955"
MARK_VILLAGE = "46981"
MARKHAM_CITY = "47007"
MARLEY_CDP = "47046"
MAROA_CITY = "47072"
MARQUETTE_HEIGHTS_CITY = "47111"
MARSEILLES_CITY = "47150"
MARSHALL_CITY = "47163"
MARTINSVILLE_CITY = "47254"
MARTINTON_VILLAGE = "47280"
MARYVILLE_VILLAGE = "47397"
MASCOUTAH_CITY = "47423"
MASON_CITY_CITY = "47475"
MASON_TOWN = "47449"
MATHERVILLE_VILLAGE = "47527"
MATTESON_VILLAGE = "47540"
MATTOON_CITY = "47553"
MAUNIE_VILLAGE = "47592"
MAYWOOD_VILLAGE = "47774"
MAZON_VILLAGE = "47787"
MCCLURE_VILLAGE = "45525"
MCCOOK_VILLAGE = "45564"
MCCULLOM_LAKE_VILLAGE = "45616"
MCHENRY_CITY = "45694"
MCLEAN_VILLAGE = "45811"
MCLEANSBORO_CITY = "45824"
MCNABB_VILLAGE = "45850"
MECHANICSBURG_VILLAGE = "48021"
MEDIA_VILLAGE = "48073"
MEDORA_VILLAGE = "48138"
MELROSE_PARK_VILLAGE = "48242"
MELVIN_VILLAGE = "48268"
MENDON_VILLAGE = "48307"
MENDOTA_CITY = "48333"
MENOMINEE_VILLAGE = "48359"
MEREDOSIA_VILLAGE = "48424"
MERRIONETTE_PARK_VILLAGE = "48554"
MERRITT_CDP = "48567"
METAMORA_VILLAGE = "48606"
METCALF_VILLAGE = "48632"
METROPOLIS_CITY = "48645"
METTAWA_VILLAGE = "48671"
MEYER_CDP = "48684"
MIDDLETOWN_VILLAGE = "48853"
MIDLOTHIAN_VILLAGE = "48892"
MILAN_VILLAGE = "49009"
MILFORD_VILLAGE = "49048"
MILL_CREEK_VILLAGE = "49178"
MILL_SHOALS_VILLAGE = "49347"
MILLBROOK_VILLAGE = "49100"
MILLEDGEVILLE_VILLAGE = "49191"
MILLERSBURG_CDP = "49243"
MILLINGTON_VILLAGE = "49308"
MILLSTADT_VILLAGE = "49386"
MILTON_VILLAGE = "49477"
MINERAL_VILLAGE = "49516"
MINIER_VILLAGE = "49555"
MINONK_CITY = "49568"
MINOOKA_VILLAGE = "49607"
MITCHELL_CDP = "49698"
MODESTO_VILLAGE = "49802"
MOKENA_VILLAGE = "49854"
MOLINE_CITY = "49867"
MOMENCE_CITY = "49893"
MONEE_VILLAGE = "49945"
MONMOUTH_CITY = "50010"
MONROE_CENTER_VILLAGE = "50062"
MONTGOMERY_VILLAGE = "50218"
MONTICELLO_CITY = "50244"
MONTROSE_VILLAGE = "50283"
MORO_CDP = "50452"
MORRIS_CITY = "50491"
MORRISON_CITY = "50530"
MORRISONVILLE_VILLAGE = "50543"
MORTON_GROVE_VILLAGE = "50647"
MORTON_VILLAGE = "50621"
MOSSVILLE_CDP = "50699"
MOUND_CITY_CITY = "50751"
MOUND_STATION_VILLAGE = "50790"
MOUNDS_CITY = "50777"
MOUNT_AUBURN_VILLAGE = "50829"
MOUNT_CARMEL_CITY = "50868"
MOUNT_CARROLL_CITY = "50881"
MOUNT_CLARE_VILLAGE = "50920"
MOUNT_ERIE_VILLAGE = "50933"
MOUNT_MORRIS_VILLAGE = "50998"
MOUNT_OLIVE_CITY = "51024"
MOUNT_PROSPECT_VILLAGE = "51089"
MOUNT_PULASKI_CITY = "51128"
MOUNT_STERLING_CITY = "51154"
MOUNT_VERNON_CITY = "51180"
MOUNT_ZION_VILLAGE = "51206"
MOWEAQUA_VILLAGE = "51232"
MUDDY_VILLAGE = "51271"
MULBERRY_GROVE_VILLAGE = "51284"
MULKEYTOWN_CDP = "51310"
MUNCIE_VILLAGE = "51336"
MUNDELEIN_VILLAGE = "51349"
MURPHYSBORO_CITY = "51453"
MURRAYVILLE_VILLAGE = "51479"
NACHUSA_CDP = "51544"
NAPERVILLE_CITY = "51622"
NAPLATE_VILLAGE = "51648"
NAPLES_TOWN = "51661"
NASHVILLE_CITY = "51700"
NASON_CITY = "51726"
NAUVOO_CITY = "51791"
NEBO_VILLAGE = "51882"
NEKOMA_CDP = "51934"
NELSON_VILLAGE = "51947"
NEOGA_CITY = "51986"
NEPONSET_VILLAGE = "51999"
NEW_ATHENS_VILLAGE = "52116"
NEW_BADEN_VILLAGE = "52142"
NEW_BEDFORD_VILLAGE = "52155"
NEW_BERLIN_VILLAGE = "52168"
NEW_BOSTON_CITY = "52220"
NEW_BURNSIDE_VILLAGE = "52285"
NEW_CANTON_TOWN = "52311"
NEW_DOUGLAS_VILLAGE = "52415"
NEW_GRAND_CHAIN_VILLAGE = "52467"
NEW_HAVEN_VILLAGE = "52506"
NEW_HOLLAND_VILLAGE = "52545"
NEW_LENOX_VILLAGE = "52584"
NEW_MILFORD_VILLAGE = "52701"
NEW_MINDEN_VILLAGE = "52714"
NEW_SALEM_VILLAGE = "52805"
NEWARK_VILLAGE = "52103"
NEWMAN_CITY = "52623"
NEWTON_CITY = "52844"
NIANTIC_VILLAGE = "52961"
NILES_VILLAGE = "53000"
NILWOOD_TOWN = "53039"
NIOTA_CDP = "53078"
NOBLE_VILLAGE = "53143"
NOKOMIS_CITY = "53169"
NORA_VILLAGE = "53195"
NORMAL_TOWN = "53234"
NORRIDGE_VILLAGE = "53377"
NORRIS_CITY_VILLAGE = "53403"
NORRIS_VILLAGE = "53390"
NORTH_AURORA_VILLAGE = "53442"
NORTH_BARRINGTON_VILLAGE = "53455"
NORTH_CHICAGO_CITY = "53559"
NORTH_CITY_VILLAGE = "53585"
NORTH_HENDERSON_VILLAGE = "53793"
NORTH_PEKIN_VILLAGE = "54092"
NORTH_RIVERSIDE_VILLAGE = "54144"
NORTH_UTICA_VILLAGE = "54222"
NORTHBROOK_VILLAGE = "53481"
NORTHFIELD_VILLAGE = "53663"
NORTHLAKE_CITY = "53871"
NORWOOD_VILLAGE = "54404"
OFALLON_CITY = "55249"
OAK_BROOK_VILLAGE = "54534"
OAK_FOREST_CITY = "54638"
OAK_GROVE_VILLAGE = "54703"
OAK_LAWN_VILLAGE = "54820"
OAK_PARK_VILLAGE = "54885"
OAK_RUN_CDP = "54924"
OAKBROOK_TERRACE_CITY = "54560"
OAKDALE_VILLAGE = "54586"
OAKFORD_VILLAGE = "54625"
OAKLAND_CITY = "54781"
OAKWOOD_HILLS_VILLAGE = "55041"
OAKWOOD_VILLAGE = "55002"
OBLONG_VILLAGE = "55106"
OCONEE_VILLAGE = "55132"
ODELL_VILLAGE = "55171"
ODIN_VILLAGE = "55210"
OGDEN_VILLAGE = "55275"
OGLESBY_CITY = "55353"
OHIO_VILLAGE = "55379"
OHLMAN_VILLAGE = "55418"
OKAWVILLE_VILLAGE = "55470"
OLD_MILL_CREEK_VILLAGE = "55639"
OLD_RIPLEY_VILLAGE = "55717"
OLD_SHAWNEETOWN_VILLAGE = "55756"
OLIVE_BRANCH_CDP = "55847"
OLIVET_CDP = "55886"
OLMSTED_VILLAGE = "55899"
OLNEY_CITY = "55912"
OLYMPIA_FIELDS_VILLAGE = "55938"
OMAHA_VILLAGE = "56003"
ONARGA_VILLAGE = "56081"
ONEIDA_CITY = "56159"
OPDYKE_CDP = "56198"
OPHIEM_CDP = "56211"
OQUAWKA_VILLAGE = "56237"
ORANGEVILLE_VILLAGE = "56341"
OREANA_VILLAGE = "56471"
OREGON_CITY = "56484"
ORIENT_CITY = "56536"
ORION_VILLAGE = "56601"
ORLAND_HILLS_VILLAGE = "56627"
ORLAND_PARK_VILLAGE = "56640"
OSCO_CDP = "56796"
OSWEGO_VILLAGE = "56887"
OTTAWA_CITY = "56926"
OTTERVILLE_TOWN = "56978"
OWANECO_VILLAGE = "57043"
OXVILLE_CDP = "57121"
PADERBORN_CDP = "57160"
PALATINE_VILLAGE = "57225"
PALESTINE_VILLAGE = "57277"
PALMER_VILLAGE = "57303"
PALMYRA_VILLAGE = "57329"
PALOMA_CDP = "57342"
PALOS_HEIGHTS_CITY = "57381"
PALOS_HILLS_CITY = "57394"
PALOS_PARK_VILLAGE = "57407"
PANA_CITY = "57472"
PANAMA_VILLAGE = "57498"
PANOLA_VILLAGE = "57524"
PAPINEAU_VILLAGE = "57576"
PARIS_CITY = "57628"
PARK_CITY_CITY = "57654"
PARK_FOREST_VILLAGE = "57732"
PARK_RIDGE_CITY = "57875"
PARKERSBURG_VILLAGE = "57693"
PATOKA_VILLAGE = "58057"
PAW_PAW_VILLAGE = "58226"
PAWNEE_VILLAGE = "58174"
PAXTON_CITY = "58239"
PAYSON_VILLAGE = "58265"
PEARL_CITY_VILLAGE = "58369"
PEARL_VILLAGE = "58343"
PECATONICA_VILLAGE = "58408"
PEKIN_CITY = "58447"
PENFIELD_CDP = "58577"
PEORIA_HEIGHTS_VILLAGE = "59026"
PEORIA_CITY = "59000"
PEOTONE_VILLAGE = "59052"
PERCY_VILLAGE = "59104"
PERRY_VILLAGE = "59156"
PERU_CITY = "59234"
PESOTUM_VILLAGE = "59273"
PETERSBURG_CITY = "59312"
PHILLIPSTOWN_VILLAGE = "59520"
PHILO_VILLAGE = "59533"
PHOENIX_VILLAGE = "59572"
PIERRON_VILLAGE = "59709"
PINCKNEYVILLE_CITY = "59884"
PINGREE_GROVE_VILLAGE = "59988"
PIPER_CITY_VILLAGE = "60079"
PISTAKEE_HIGHLANDS_CDP = "60144"
PITTSBURG_VILLAGE = "60209"
PITTSFIELD_CITY = "60222"
PLAINFIELD_VILLAGE = "60287"
PLAINVILLE_VILLAGE = "60339"
PLANO_CITY = "60352"
PLATTVILLE_VILLAGE = "60391"
PLEASANT_HILL_VILLAGE = "60534"
PLEASANT_PLAINS_VILLAGE = "60599"
PLUM_VALLEY_CDP = "60826"
PLYMOUTH_VILLAGE = "60833"
POCAHONTAS_VILLAGE = "60872"
POLO_CITY = "60937"
PONTIAC_CITY = "61015"
PONTOON_BEACH_VILLAGE = "61067"
PONTOOSUC_VILLAGE = "61080"
POPLAR_GROVE_VILLAGE = "61145"
PORT_BARRINGTON_VILLAGE = "61216"
PORT_BYRON_VILLAGE = "61223"
POSEN_VILLAGE = "61314"
POTOMAC_VILLAGE = "61366"
PRAIRIE_CITY_VILLAGE = "61548"
PRAIRIE_GROVE_VILLAGE = "61678"
PRAIRIE_DU_ROCHER_VILLAGE = "61639"
PRAIRIETOWN_CDP = "61743"
PREEMPTION_CDP = "61782"
PRESTBURY_CDP = "61821"
PRESTON_HEIGHTS_CDP = "61860"
PRINCETON_CITY = "61899"
PRINCEVILLE_VILLAGE = "61925"
PROPHETSTOWN_CITY = "61977"
PROSPECT_HEIGHTS_CITY = "62016"
PULASKI_VILLAGE = "62211"
QUINCY_CITY = "62367"
RADOM_VILLAGE = "62523"
RALEIGH_VILLAGE = "62588"
RAMSEY_VILLAGE = "62627"
RANKIN_VILLAGE = "62744"
RANSOM_VILLAGE = "62757"
RANTOUL_VILLAGE = "62783"
RAPIDS_CITY_VILLAGE = "62822"
RARITAN_VILLAGE = "62848"
RAYMOND_VILLAGE = "62965"
RED_BUD_CITY = "63043"
REDDICK_VILLAGE = "63056"
REDMON_VILLAGE = "63069"
RENTCHLER_CDP = "63355"
REST_HAVEN_CDP = "63382"
REYNOLDS_VILLAGE = "63420"
RICHFIELD_CDP = "63537"
RICHMOND_VILLAGE = "63641"
RICHTON_PARK_VILLAGE = "63706"
RICHVIEW_VILLAGE = "63719"
RIDGE_FARM_VILLAGE = "63862"
RIDGEFIELD_CDP = "63875"
RIDGEWOOD_CDP = "64005"
RIDGWAY_VILLAGE = "64018"
RIDOTT_VILLAGE = "64044"
RIGGSTON_CDP = "64083"
RILEY_CDP = "64094"
RINGWOOD_VILLAGE = "64135"
RIO_VILLAGE = "64148"
RIPLEY_VILLAGE = "64174"
RITCHIE_CDP = "64239"
RIVER_FOREST_VILLAGE = "64304"
RIVER_GROVE_VILLAGE = "64343"
RIVERDALE_VILLAGE = "64278"
RIVERSIDE_VILLAGE = "64421"
RIVERTON_VILLAGE = "64486"
RIVERWOODS_VILLAGE = "64538"
ROANOKE_VILLAGE = "64590"
ROBBINS_VILLAGE = "64616"
ROBERTS_VILLAGE = "64655"
ROBINSON_CITY = "64707"
ROCHELLE_CITY = "64746"
ROCHESTER_VILLAGE = "64759"
ROCK_CITY_VILLAGE = "64837"
ROCK_FALLS_CITY = "64928"
ROCK_ISLAND_ARSENAL_CDP = "65104"
ROCK_ISLAND_CITY = "65078"
ROCKBRIDGE_VILLAGE = "64811"
ROCKDALE_VILLAGE = "64902"
ROCKFORD_CITY = "65000"
ROCKPORT_CDP = "65130"
ROCKTON_VILLAGE = "65156"
ROCKWOOD_VILLAGE = "65221"
ROLLING_MEADOWS_CITY = "65338"
ROME_CDP = "65403"
ROMEOVILLE_VILLAGE = "65442"
ROODHOUSE_CITY = "65481"
ROSCOE_VILLAGE = "65611"
ROSE_HILL_VILLAGE = "65754"
ROSELLE_VILLAGE = "65806"
ROSEMONT_VILLAGE = "65819"
ROSEVILLE_VILLAGE = "65845"
ROSEWOOD_HEIGHTS_CDP = "65884"
ROSICLARE_CITY = "65897"
ROSSVILLE_VILLAGE = "65962"
ROUND_LAKE_BEACH_VILLAGE = "66040"
ROUND_LAKE_HEIGHTS_VILLAGE = "66053"
ROUND_LAKE_PARK_VILLAGE = "66066"
ROUND_LAKE_VILLAGE = "66027"
ROXANA_VILLAGE = "66131"
ROYAL_LAKES_VILLAGE = "66196"
ROYAL_VILLAGE = "66157"
ROYALTON_VILLAGE = "66209"
RUMA_VILLAGE = "66287"
RUSHVILLE_CITY = "66339"
RUSSELLVILLE_VILLAGE = "66404"
RUTLAND_VILLAGE = "66443"
SADORUS_VILLAGE = "66534"
SAILOR_SPRINGS_VILLAGE = "66599"
SALEM_CITY = "67236"
SAMMONS_POINT_VILLAGE = "67372"
SAN_JOSE_VILLAGE = "67613"
SANDOVAL_VILLAGE = "67444"
SANDWICH_CITY = "67548"
SAUGET_VILLAGE = "67756"
SAUK_VILLAGE_VILLAGE = "67769"
SAUNEMIN_VILLAGE = "67795"
SAVANNA_CITY = "67821"
SAVOY_VILLAGE = "67860"
SAWYERVILLE_VILLAGE = "67873"
SAYBROOK_VILLAGE = "67912"
SCALES_MOUND_VILLAGE = "67925"
SCHAUMBURG_VILLAGE = "68003"
SCHILLER_PARK_VILLAGE = "68081"
SCHRAM_CITY_VILLAGE = "68120"
SCIOTA_VILLAGE = "68198"
SCOTT_AFB_CDP = "68328"
SCOTTVILLE_VILLAGE = "68406"
SEATON_VILLAGE = "68458"
SEATONVILLE_VILLAGE = "68471"
SECOR_VILLAGE = "68510"
SENECA_VILLAGE = "68640"
SERENA_CDP = "68679"
SESSER_CITY = "68705"
SEYMOUR_CDP = "68809"
SHABBONA_VILLAGE = "68822"
SHANNON_VILLAGE = "68991"
SHAWNEETOWN_CITY = "69082"
SHEFFIELD_VILLAGE = "69147"
SHELBYVILLE_CITY = "69186"
SHELDON_VILLAGE = "69212"
SHERIDAN_VILLAGE = "69277"
SHERMAN_VILLAGE = "69342"
SHERRARD_VILLAGE = "69368"
SHILOH_VILLAGE = "69524"
SHIPMAN_TOWN = "69563"
SHIRLEY_CDP = "69628"
SHOREWOOD_VILLAGE = "69758"
SHUMWAY_VILLAGE = "69797"
SIBLEY_VILLAGE = "69810"
SIDELL_VILLAGE = "69836"
SIDNEY_VILLAGE = "69875"
SIGEL_TOWN = "69914"
SILVIS_CITY = "69979"
SIMPSON_VILLAGE = "70005"
SIMS_VILLAGE = "70031"
SKOKIE_VILLAGE = "70122"
SLEEPY_HOLLOW_VILLAGE = "70161"
SMITHBORO_VILLAGE = "70213"
SMITHFIELD_VILLAGE = "70226"
SMITHTON_VILLAGE = "70252"
SMITHVILLE_CDP = "70278"
SOLON_MILLS_CDP = "70356"
SOMONAUK_VILLAGE = "70460"
SORENTO_VILLAGE = "70525"
SOUTH_BARRINGTON_VILLAGE = "70564"
SOUTH_BELOIT_CITY = "70590"
SOUTH_CHICAGO_HEIGHTS_VILLAGE = "70629"
SOUTH_ELGIN_VILLAGE = "70720"
SOUTH_HOLLAND_VILLAGE = "70850"
SOUTH_JACKSONVILLE_VILLAGE = "70889"
SOUTH_PEKIN_VILLAGE = "71175"
SOUTH_ROXANA_VILLAGE = "71240"
SOUTH_WILMINGTON_VILLAGE = "71370"
SOUTHERN_VIEW_VILLAGE = "70759"
SPARLAND_VILLAGE = "71422"
SPARTA_CITY = "71448"
SPAULDING_VILLAGE = "71474"
SPILLERTOWN_VILLAGE = "71526"
SPRING_BAY_VILLAGE = "71604"
SPRING_GROVE_VILLAGE = "72052"
SPRING_VALLEY_CITY = "72156"
SPRINGERTON_VILLAGE = "71643"
SPRINGFIELD_CITY = "72000"
ST_ANNE_VILLAGE = "66638"
ST_AUGUSTINE_VILLAGE = "66677"
ST_CHARLES_CITY = "66703"
ST_DAVID_VILLAGE = "66768"
ST_ELMO_CITY = "66794"
ST_FRANCISVILLE_CITY = "66833"
ST_JACOB_VILLAGE = "66859"
ST_JOHNS_VILLAGE = "66924"
ST_JOSEPH_VILLAGE = "66950"
ST_LIBORY_VILLAGE = "66989"
ST_PETER_VILLAGE = "67132"
ST_ROSE_VILLAGE = "67158"
STANDARD_CITY_VILLAGE = "72234"
STANDARD_VILLAGE = "72221"
STANFORD_VILLAGE = "72260"
STAUNTON_CITY = "72403"
STE_MARIE_VILLAGE = "66800"
STEELEVILLE_VILLAGE = "72468"
STEGER_VILLAGE = "72520"
STERLING_CITY = "72546"
STEWARD_VILLAGE = "72624"
STEWARDSON_VILLAGE = "72650"
STICKNEY_VILLAGE = "72676"
STILLMAN_VALLEY_VILLAGE = "72702"
STOCKTON_VILLAGE = "72780"
STONE_PARK_VILLAGE = "72923"
STONEFORT_VILLAGE = "72884"
STONINGTON_VILLAGE = "72949"
STOY_VILLAGE = "73027"
STRASBURG_VILLAGE = "73040"
STRAWN_VILLAGE = "73131"
STREAMWOOD_VILLAGE = "73157"
STREATOR_CITY = "73170"
STRONGHURST_VILLAGE = "73261"
SUBLETTE_VILLAGE = "73287"
SUGAR_GROVE_VILLAGE = "73391"
SULLIVAN_CITY = "73495"
SUMMERFIELD_VILLAGE = "73547"
SUMMIT_VILLAGE = "73638"
SUMNER_CITY = "73703"
SUN_RIVER_TERRACE_VILLAGE = "73943"
SUNNYLAND_CDP = "73872"
SWANSEA_VILLAGE = "74119"
SWEDONA_CDP = "74145"
SYCAMORE_CITY = "74223"
SYMERTON_VILLAGE = "74275"
TABLE_GROVE_VILLAGE = "74301"
TALLULA_VILLAGE = "74379"
TAMAROA_VILLAGE = "74444"
TAMMS_VILLAGE = "74457"
TAMPICO_VILLAGE = "74470"
TAYLOR_RIDGE_CDP = "74548"
TAYLOR_SPRINGS_VILLAGE = "74561"
TAYLORVILLE_CITY = "74574"
TENNESSEE_VILLAGE = "74665"
TEUTOPOLIS_VILLAGE = "74743"
THAWVILLE_VILLAGE = "74847"
THAYER_VILLAGE = "74860"
THE_GALENA_TERRITORY_CDP = "74970"
THEBES_VILLAGE = "74873"
THIRD_LAKE_VILLAGE = "75081"
THOMASBORO_VILLAGE = "75107"
THOMPSONVILLE_VILLAGE = "75159"
THOMSON_VILLAGE = "75172"
THORNTON_VILLAGE = "75185"
TILDEN_VILLAGE = "75263"
TILTON_VILLAGE = "75276"
TIMBERLANE_VILLAGE = "75360"
TIME_VILLAGE = "75419"
TINLEY_PARK_VILLAGE = "75484"
TISKILWA_VILLAGE = "75549"
TOLEDO_VILLAGE = "75601"
TOLONO_VILLAGE = "75614"
TOLUCA_CITY = "75653"
TONICA_VILLAGE = "75718"
TOPEKA_VILLAGE = "75757"
TOULON_CITY = "75783"
TOVEY_VILLAGE = "75809"
TOWANDA_VILLAGE = "75822"
TOWER_HILL_VILLAGE = "75848"
TOWER_LAKES_VILLAGE = "75874"
TREMONT_VILLAGE = "75965"
TRENTON_CITY = "75991"
TRILLA_CDP = "76017"
TRIUMPH_CDP = "76082"
TRIVOLI_CDP = "76108"
TROUT_VALLEY_VILLAGE = "76160"
TROY_GROVE_VILLAGE = "76225"
TROY_CITY = "76199"
TUSCOLA_CITY = "76407"
TWIN_GROVE_CDP = "76511"
ULLIN_VILLAGE = "76615"
UNION_HILL_VILLAGE = "76771"
UNION_VILLAGE = "76706"
UNITY_CDP = "76875"
UNIVERSITY_PARK_VILLAGE = "76935"
URBANA_CITY = "77005"
URSA_VILLAGE = "77044"
VALIER_VILLAGE = "77148"
VALLEY_CITY_VILLAGE = "77187"
VALMEYER_VILLAGE = "77265"
VANDALIA_CITY = "77317"
VARNA_VILLAGE = "77395"
VENEDY_VILLAGE = "77408"
VENETIAN_VILLAGE_CDP = "77460"
VENICE_CITY = "77473"
VERGENNES_VILLAGE = "77525"
VERMILION_VILLAGE = "77551"
VERMONT_VILLAGE = "77642"
VERNON_HILLS_VILLAGE = "77694"
VERNON_VILLAGE = "77681"
VERONA_VILLAGE = "77707"
VERSAILLES_VILLAGE = "77720"
VICTORIA_VILLAGE = "77811"
VIENNA_CITY = "77863"
VILLA_GROVE_CITY = "77941"
VILLA_PARK_VILLAGE = "77993"
VIOLA_VILLAGE = "78123"
VIRDEN_CITY = "78149"
VIRGIL_VILLAGE = "78175"
VIRGINIA_CITY = "78201"
VOLO_VILLAGE = "78227"
WADSWORTH_VILLAGE = "78370"
WAGGONER_VILLAGE = "78383"
WALNUT_HILL_VILLAGE = "78604"
WALNUT_VILLAGE = "78526"
WALSHVILLE_VILLAGE = "78656"
WALTONVILLE_VILLAGE = "78708"
WAMAC_CITY = "78721"
WAPELLA_VILLAGE = "78773"
WARREN_VILLAGE = "78851"
WARRENSBURG_VILLAGE = "78916"
WARRENVILLE_CITY = "78929"
WARSAW_CITY = "78942"
WASHBURN_VILLAGE = "79007"
WASHINGTON_PARK_VILLAGE = "79085"
WASHINGTON_CITY = "79033"
WATAGA_VILLAGE = "79124"
WATERLOO_CITY = "79150"
WATERMAN_VILLAGE = "79163"
WATSEKA_CITY = "79228"
WATSON_VILLAGE = "79241"
WAUCONDA_VILLAGE = "79267"
WAUKEGAN_CITY = "79293"
WAVERLY_CITY = "79358"
WAYNE_CITY_VILLAGE = "79436"
WAYNE_VILLAGE = "79397"
WAYNESVILLE_VILLAGE = "79449"
WEDRON_CDP = "79618"
WELDON_VILLAGE = "79683"
WELLINGTON_VILLAGE = "79735"
WENONA_CITY = "79813"
WENONAH_VILLAGE = "79826"
WEST_BROOKLYN_VILLAGE = "80008"
WEST_CHICAGO_CITY = "80060"
WEST_CITY_VILLAGE = "80073"
WEST_DUNDEE_VILLAGE = "80125"
WEST_FRANKFORT_CITY = "80333"
WEST_LIBERTY_CDP = "80580"
WEST_PEORIA_CITY = "80736"
WEST_POINT_VILLAGE = "80762"
WEST_SALEM_VILLAGE = "80853"
WEST_UNION_CDP = "80879"
WEST_YORK_CDP = "80957"
WESTCHESTER_VILLAGE = "80047"
WESTERN_SPRINGS_VILLAGE = "80242"
WESTERVELT_CDP = "80255"
WESTFIELD_VILLAGE = "80281"
WESTLAKE_VILLAGE_CDP = "80570"
WESTMONT_VILLAGE = "80645"
WESTVILLE_VILLAGE = "80931"
WHEATON_CITY = "81048"
WHEELER_VILLAGE = "81074"
WHEELING_VILLAGE = "81087"
WHITE_CITY_VILLAGE = "81191"
WHITE_HALL_CITY = "81256"
WHITE_HEATH_CDP = "81295"
WHITEASH_CDP = "81165"
WILLIAMSFIELD_VILLAGE = "81802"
WILLIAMSON_VILLAGE = "81815"
WILLIAMSVILLE_VILLAGE = "81854"
WILLISVILLE_VILLAGE = "81867"
WILLOW_HILL_VILLAGE = "82010"
WILLOW_LAKE_CDP = "82029"
WILLOW_SPRINGS_VILLAGE = "82049"
WILLOWBROOK_CDP = "81938"
WILLOWBROOK_VILLAGE = "81919"
WILMETTE_VILLAGE = "82075"
WILMINGTON_CITY = "82101"
WILMINGTON_VILLAGE = "82088"
WILSONVILLE_VILLAGE = "82218"
WILTON_CENTER_CDP = "82257"
WINCHESTER_CITY = "82270"
WINDSOR_CITY = "82322"
WINDSOR_VILLAGE = "82309"
WINFIELD_VILLAGE = "82400"
WINNEBAGO_VILLAGE = "82491"
WINNETKA_VILLAGE = "82530"
WINSLOW_VILLAGE = "82543"
WINTHROP_HARBOR_VILLAGE = "82686"
WITT_CITY = "82725"
WONDER_LAKE_VILLAGE = "82855"
WOOD_DALE_CITY = "82985"
WOOD_RIVER_CITY = "83271"
WOODHULL_VILLAGE = "83063"
WOODLAND_VILLAGE = "83102"
WOODLAWN_VILLAGE = "83206"
WOODRIDGE_VILLAGE = "83245"
WOODSON_VILLAGE = "83336"
WOODSTOCK_CITY = "83349"
WORDEN_VILLAGE = "83505"
WORTH_VILLAGE = "83518"
WYANET_VILLAGE = "83622"
WYOMING_CITY = "83687"
XENIA_VILLAGE = "83739"
YALE_VILLAGE = "83765"
YATES_CITY_VILLAGE = "83817"
YORKVILLE_CITY = "84038"
ZEIGLER_CITY = "84155"
ZION_CITY = "84220"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New York."""


ALBANY = "001"
ALLEGANY = "003"
BRONX = "005"
BROOME = "007"
CATTARAUGUS = "009"
CAYUGA = "011"
CHAUTAUQUA = "013"
CHEMUNG = "015"
CHENANGO = "017"
CLINTON = "019"
COLUMBIA = "021"
CORTLAND = "023"
DELAWARE = "025"
DUTCHESS = "027"
ERIE = "029"
ESSEX = "031"
FRANKLIN = "033"
FULTON = "035"
GENESEE = "037"
GREENE = "039"
HAMILTON = "041"
HERKIMER = "043"
JEFFERSON = "045"
KINGS = "047"
LEWIS = "049"
LIVINGSTON = "051"
MADISON = "053"
MONROE = "055"
MONTGOMERY = "057"
NASSAU = "059"
NEW_YORK = "061"
NIAGARA = "063"
ONEIDA = "065"
ONONDAGA = "067"
ONTARIO = "069"
ORANGE = "071"
ORLEANS = "073"
OSWEGO = "075"
OTSEGO = "077"
PUTNAM = "079"
QUEENS = "081"
RENSSELAER = "083"
RICHMOND = "085"
ROCKLAND = "087"
SARATOGA = "091"
SCHENECTADY = "093"
SCHOHARIE = "095"
SCHUYLER = "097"
SENECA = "099"
ST_LAWRENCE = "089"
STEUBEN = "101"
SUFFOLK = "103"
SULLIVAN = "105"
TIOGA = "107"
TOMPKINS = "109"
ULSTER = "111"
WARREN = "113"
WASHINGTON = "115"
WAYNE = "117"
WESTCHESTER = "119"
WYOMING = "121"
YATES = "123"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Connecticut."""


ANSONIA_CITY = "01150"
BALL_POND_CDP = "02480"
BALTIC_CDP = "02550"
BANTAM_BOROUGH = "02690"
BETHEL_CDP = "04790"
BETHLEHEM_VILLAGE_CDP = "04945"
BIGELOW_CORNERS_CDP = "04965"
BLUE_HILLS_CDP = "06050"
BOGUS_HILL_CDP = "06155"
BOTSFORD_CDP = "06680"
BRANCHVILLE_CDP = "07100"
BRANFORD_CENTER_CDP = "07345"
BRIDGEPORT_CITY = "08000"
BRIDGEWATER_CDP = "08140"
BRISTOL_CITY = "08420"
BROAD_BROOK_CDP = "08770"
BROOKFIELD_CENTER_CDP = "09050"
BROOKLYN_CDP = "09120"
BYRAM_CDP = "10660"
CANAAN_CDP = "10870"
CANDLEWOOD_ISLE_CDP = "11360"
CANDLEWOOD_KNOLLS_CDP = "11430"
CANDLEWOOD_LAKE_CLUB_CDP = "11500"
CANDLEWOOD_ORCHARDS_CDP = "11640"
CANDLEWOOD_SHORES_CDP = "11780"
CANNONDALE_CDP = "11990"
CANTON_VALLEY_CDP = "12370"
CHESHIRE_VILLAGE_CDP = "14200"
CHESTER_CENTER_CDP = "14370"
CHIMNEY_POINT_CDP = "14615"
CLINTON_CDP = "15420"
COLCHESTER_CDP = "15840"
COLEYTOWN_CDP = "16085"
COLLINSVILLE_CDP = "16120"
COMPO_CDP = "16525"
CONNING_TOWERS_NAUTILUS_PARK_CDP = "16960"
CORNWALL_BRIDGE_CDP = "17310"
CORNWALL_CDP = "17170"
COS_COB_CDP = "17520"
COVENTRY_LAKE_CDP = "17835"
CRYSTAL_LAKE_CDP = "18220"
DANBURY_CITY = "18430"
DANIELS_FARM_CDP = "18675"
DANIELSON_BOROUGH = "18780"
DARIEN_DOWNTOWN_CDP = "18936"
DAYVILLE_CDP = "18990"
DEEP_RIVER_CENTER_CDP = "19200"
DERBY_CITY = "19480"
DODGINGTOWN_CDP = "20250"
DURHAM_CDP = "20740"
EAST_BROOKLYN_CDP = "21160"
EAST_HAMPTON_CDP = "22420"
EAST_HARTFORD_CDP = "22700"
EAST_HAVEN_CDP = "22980"
EAST_VILLAGE_CDP = "24520"
ESSEX_VILLAGE_CDP = "26370"
FAIRFIELD_UNIVERSITY_CDP = "26698"
FALLS_VILLAGE_CDP = "27390"
FENWICK_BOROUGH = "27810"
GALES_FERRY_CDP = "30190"
GAYLORDSVILLE_CDP = "30470"
GEORGETOWN_CDP = "30540"
GLASTONBURY_CENTER_CDP = "31270"
GLENVILLE_CDP = "31520"
GREENS_FARMS_CDP = "33480"
GREENWICH_CDP = "33690"
GROTON_LONG_POINT_BOROUGH = "34460"
GROTON_CITY = "34180"
GUILFORD_CENTER_CDP = "35020"
HARTFORD_CITY = "37000"
HAWLEYVILLE_CDP = "37490"
HAZARDVILLE_CDP = "37770"
HERITAGE_VILLAGE_CDP = "37930"
HIGGANUM_CDP = "38050"
INDIAN_FIELD_CDP = "39695"
INGLENOOK_CDP = "39747"
JEWETT_CITY_BOROUGH = "39940"
KELLOGG_POINT_CDP = "40077"
KENSINGTON_CDP = "40150"
KNOLLCREST_CDP = "40920"
LAKE_BUNGEE_CDP = "41226"
LAKE_CHAFFEE_CDP = "41238"
LAKE_POCOTOPAUG_CDP = "41410"
LAKES_EAST_CDP = "41585"
LAKES_WEST_CDP = "41736"
LAKESIDE_WOODS_CDP = "41714"
LAKEVILLE_CDP = "41830"
LITCHFIELD_BOROUGH = "43300"
LONG_HILL_CDP_GREATER_BRIDGEPORT_COUNTY = "43580"
LONG_HILL_CDP_SOUTHEASTERN_CONNECTICUT_COUNTY = "43790"
LORDSHIP_CDP = "44000"
MADISON_CENTER_CDP = "44630"
MAMANASCO_LAKE_CDP = "44660"
MANCHESTER_CDP = "44690"
MANSFIELD_CENTER_CDP = "45120"
MASHANTUCKET_CDP = "45995"
MECHANICSVILLE_CDP = "46240"
MERIDEN_CITY = "46450"
MIDDLETOWN_CITY = "47290"
MILFORD_CITY_BALANCE = "47515"
MILL_PLAIN_CDP = "47990"
MOODUS_CDP = "49110"
MOOSUP_CDP = "49180"
MURRAY_CDP = "49720"
MYSTIC_CDP = "49810"
NAUGATUCK_BOROUGH = "49880"
NEW_BRITAIN_CITY = "50370"
NEW_CANAAN_CDP = "50576"
NEW_HARTFORD_CENTER_CDP = "51420"
NEW_HAVEN_CITY = "52000"
NEW_LONDON_CITY = "52280"
NEW_MILFORD_CDP = "52560"
NEW_PRESTON_CDP = "52770"
NEWINGTON_CDP = "52210"
NEWTOWN_BOROUGH = "52910"
NIANTIC_CDP = "53120"
NOANK_CDP = "53260"
NORFOLK_CDP = "53400"
NOROTON_CDP = "53540"
NOROTON_HEIGHTS_CDP = "53610"
NORTH_GRANBY_CDP = "54660"
NORTH_GROSVENOR_DALE_CDP = "54730"
NORTH_HAVEN_CDP = "54940"
NORTHFORD_CDP = "54450"
NORTHWEST_HARWINTON_CDP = "55725"
NORWALK_CITY = "55990"
NORWICH_CITY = "56200"
OAKVILLE_CDP = "56690"
OLD_GREENWICH_CDP = "56900"
OLD_HILL_CDP = "56935"
OLD_MYSTIC_CDP = "57180"
OLD_SAYBROOK_CENTER_CDP = "57390"
ORANGE_CDP = "57670"
ORONOQUE_CDP = "57880"
OXOBOXO_RIVER_CDP = "58520"
PAWCATUCK_CDP = "59140"
PEMBERWICK_CDP = "59210"
PLAINFIELD_VILLAGE_CDP = "60090"
PLANTSVILLE_CDP = "60260"
PLATTSVILLE_CDP = "60365"
PLEASANT_VALLEY_CDP = "60540"
POPLAR_PLAINS_CDP = "61555"
POQUONOCK_BRIDGE_CDP = "61730"
PORTLAND_CDP = "61870"
PUTNAM_CDP = "62640"
QUASSET_LAKE_CDP = "63165"
QUINEBAUG_CDP = "63270"
QUINNIPIAC_UNIVERSITY_CDP = "63313"
REDDING_CENTER_CDP = "63620"
RIDGEBURY_CDP = "63830"
RIDGEFIELD_CDP = "63900"
RIVERSIDE_CDP = "64530"
RIVERTON_CDP = "64880"
ROCK_RIDGE_CDP = "65160"
ROCKVILLE_CDP = "65230"
ROUTE_7_GATEWAY_CDP = "65685"
SACRED_HEART_UNIVERSITY_CDP = "66086"
SAIL_HARBOR_CDP = "66113"
SALMON_BROOK_CDP = "66455"
SANDY_HOOK_CDP = "66700"
SAUGATUCK_CDP = "66770"
SAYBROOK_MANOR_CDP = "67050"
SHARON_CDP = "67890"
SHELTON_CITY = "68100"
SHERMAN_CDP = "68240"
SHERWOOD_MANOR_CDP = "68450"
SIMSBURY_CENTER_CDP = "69010"
SOMERS_CDP = "69150"
SOUTH_COVENTRY_CDP = "69990"
SOUTH_WILTON_CDP = "71215"
SOUTH_WINDHAM_CDP = "71250"
SOUTH_WOODSTOCK_CDP = "71530"
SOUTHPORT_CDP = "71040"
SOUTHWOOD_ACRES_CDP = "71460"
STAFFORD_SPRINGS_CDP = "72300"
STAMFORD_CITY = "73000"
STAPLES_CDP = "73175"
STEPNEY_CDP = "73280"
STONINGTON_BOROUGH = "73700"
STORRS_CDP = "73980"
STRATFORD_DOWNTOWN_CDP = "74303"
SUFFIELD_DEPOT_CDP = "74655"
TARIFFVILLE_CDP = "75100"
TASHUA_CDP = "75116"
TAYLOR_CORNERS_CDP = "75065"
TERRAMUGGUS_CDP = "75200"
TERRYVILLE_CDP = "75240"
THOMASTON_CDP = "75660"
THOMPSONVILLE_CDP = "75940"
TOKENEKE_CDP = "76150"
TOPSTONE_CDP = "76400"
TORRINGTON_CITY = "76500"
TRUMBULL_CENTER_CDP = "77278"
WALLINGFORD_CENTER_CDP = "78880"
WATERBURY_CITY = "80000"
WATERFORD_CDP = "80210"
WATERTOWN_CDP = "80420"
WAUREGAN_CDP = "80630"
WEATOGUE_CDP = "80770"
WEST_CORNWALL_CDP = "82030"
WEST_HARTFORD_CDP = "82660"
WEST_HAVEN_CITY = "82800"
WEST_MOUNTAIN_CDP = "83045"
WEST_SIMSBURY_CDP = "83990"
WESTBROOK_CENTER_CDP = "81750"
WESTON_CDP = "83360"
WESTPORT_VILLAGE_CDP = "83586"
WETHERSFIELD_CDP = "84970"
WILLIMANTIC_CDP = "85810"
WILTON_CENTER_CDP = "86380"
WINDSOR_LOCKS_CDP = "87140"
WINSTED_CDP = "87350"
WITCHES_WOODS_CDP = "87455"
WOODBURY_CENTER_CDP = "87980"
WOODMONT_BOROUGH = "88050"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in South Carolina."""


ABBEVILLE_CITY = "00100"
ABNEY_CROSSROADS_CDP = "00165"
ADAMS_RUN_CDP = "00370"
AIKEN_CITY = "00550"
ALCOLU_CDP = "00775"
ALLENDALE_TOWN = "00955"
ANDERSON_CITY = "01360"
ANDREWS_TOWN = "01450"
ANTREVILLE_CDP = "01810"
ARCADIA_CDP = "02080"
ARCADIA_LAKES_TOWN = "02125"
ARIAL_CDP = "02440"
ARKWRIGHT_CDP = "02530"
ARTHURTOWN_CDP = "02665"
ASHWOOD_CDP = "03115"
ATLANTIC_BEACH_TOWN = "03205"
AWENDAW_TOWN = "03385"
AYNOR_TOWN = "03430"
BAMBERG_TOWN = "03790"
BARNWELL_CITY = "04060"
BATESBURG_LEESVILLE_TOWN = "04300"
BAXTER_VILLAGE_CDP = "04528"
BEAUFORT_CITY = "04690"
BEECH_ISLAND_CDP = "04915"
BELTON_CITY = "05365"
BELVEDERE_CDP = "05410"
BEN_AVON_CDP = "05545"
BENNETTSVILLE_CITY = "05680"
BEREA_CDP = "05770"
BETHUNE_TOWN = "06040"
BISHOPVILLE_CITY = "06310"
BLACKSBURG_TOWN = "06400"
BLACKVILLE_TOWN = "06490"
BLENHEIM_TOWN = "06850"
BLUFFTON_TOWN = "07210"
BLYTHEWOOD_TOWN = "07255"
BOILING_SPRINGS_CDP = "07345"
BONNEAU_BEACH_CDP = "07535"
BONNEAU_TOWN = "07525"
BOWMAN_TOWN = "07840"
BOYKIN_CDP = "08110"
BRADLEY_CDP = "08155"
BRANCHVILLE_TOWN = "08245"
BRIARCLIFFE_ACRES_TOWN = "08830"
BROOKDALE_CDP = "09527"
BROWNTOWN_CDP = "09782"
BRUNSON_TOWN = "09865"
BUCKSPORT_CDP = "10000"
BUFFALO_CDP = "10090"
BUFORD_CDP = "10135"
BURNETTOWN_TOWN = "10270"
BURTON_CDP = "10360"
CAESARS_HEAD_CDP = "10585"
CALHOUN_FALLS_TOWN = "10720"
CAMDEN_CITY = "10855"
CAMERON_TOWN = "10900"
CAMP_CROFT_CDP = "11035"
CAMPOBELLO_TOWN = "11125"
CANE_SAVANNAH_CDP = "11350"
CAPITOL_VIEW_CDP = "11620"
CARLISLE_TOWN = "11755"
CAROLINA_FOREST_CDP = "11833"
CASH_CDP = "12205"
CATAWBA_CDP = "12430"
CATEECHEE_CDP = "12520"
CAYCE_CITY = "12655"
CENTENARY_CDP = "12925"
CENTERVILLE_CDP = "12965"
CENTRAL_PACOLET_TOWN = "13060"
CENTRAL_TOWN = "13015"
CHAPIN_TOWN = "13150"
CHARLESTON_CITY = "13330"
CHERAW_TOWN = "13600"
CHEROKEE_FALLS_CDP = "13735"
CHERRYVALE_CDP = "14018"
CHESNEE_CITY = "14050"
CHESTER_CITY = "14095"
CHESTERFIELD_TOWN = "14140"
CHICKASAW_POINT_CDP = "14230"
CITY_VIEW_CDP = "14455"
CLARKS_HILL_CDP = "14590"
CLEARWATER_CDP = "14860"
CLEMSON_UNIVERSITY_CDP = "15040"
CLEMSON_CITY = "14950"
CLIFTON_CDP = "15220"
CLINTON_CITY = "15295"
CLIO_TOWN = "15310"
CLOVER_TOWN = "15355"
COKESBURY_CDP = "15625"
COLUMBIA_CITY = "16000"
CONESTEE_CDP = "16180"
CONVERSE_CDP = "16360"
CONWAY_CITY = "16405"
COOSAWHATCHIE_CDP = "16675"
COPE_TOWN = "16720"
CORDOVA_TOWN = "16855"
CORONACA_CDP = "16945"
COTTAGEVILLE_TOWN = "16990"
COWARD_TOWN = "17215"
COWPENS_TOWN = "17260"
CROSS_ANCHOR_CDP = "17845"
CROSS_HILL_TOWN = "17890"
DACUSVILLE_CDP = "18250"
DALE_CDP = "18340"
DALZELL_CDP = "18430"
DANWOOD_CDP = "18475"
DARLINGTON_CITY = "18565"
DAUFUSKIE_ISLAND_CDP = "18610"
DAVISTON_CDP = "18706"
DEBORDIEU_COLONY_CDP = "18810"
DENMARK_CITY = "19105"
DENTSVILLE_CDP = "19285"
DILLON_CITY = "19420"
DONALDS_TOWN = "19870"
DOVESVILLE_CDP = "20365"
DRAYTON_CDP = "20590"
DUE_WEST_TOWN = "21040"
DUNBAR_CDP = "21130"
DUNCAN_TOWN = "21265"
DUNEAN_CDP = "21310"
EASLEY_CITY = "21985"
EAST_CAMDEN_CDP = "22050"
EAST_GAFFNEY_CDP = "22075"
EAST_SUMTER_CDP = "22547"
EASTOVER_TOWN = "22390"
EDGEFIELD_TOWN = "22795"
EDISTO_BEACH_TOWN = "23020"
EDISTO_CDP = "22997"
EDMUND_CDP = "23110"
EHRHARDT_TOWN = "23200"
ELGIN_CDP = "23290"
ELGIN_TOWN = "23245"
ELKO_TOWN = "23335"
ELLIOTT_CDP = "23425"
ELLOREE_TOWN = "23470"
ENOREE_CDP = "23605"
ESTILL_TOWN = "23830"
EUREKA_MILL_CDP = "24020"
EUTAWVILLE_TOWN = "24100"
FAIR_PLAY_CDP = "24730"
FAIRFAX_TOWN = "24370"
FAIRFOREST_CDP = "24505"
FAIRVIEW_CROSSROADS_CDP = "24865"
FINGERVILLE_CDP = "25360"
FINKLEA_CDP = "25405"
FIVE_FORKS_CDP = "25540"
FLORENCE_CITY = "25810"
FLOYDALE_CDP = "25945"
FOLLY_BEACH_CITY = "26035"
FOREST_ACRES_CITY = "26305"
FORESTBROOK_CDP = "26372"
FORESTON_CDP = "26485"
FORT_LAWN_TOWN = "26845"
FORT_MILL_TOWN = "26890"
FOUNTAIN_INN_CITY = "27070"
FRIPP_ISLAND_CDP = "27565"
FURMAN_TOWN = "27835"
GADSDEN_CDP = "27970"
GAFFNEY_CITY = "28060"
GANTT_CDP = "28375"
GARDEN_CITY_CDP = "28455"
GASTON_TOWN = "28780"
GAYLE_MILL_CDP = "28825"
GEORGETOWN_CITY = "28870"
GIFFORD_TOWN = "29005"
GILBERT_TOWN = "29050"
GILLISONVILLE_CDP = "29140"
GLENDALE_CDP = "29275"
GLENN_SPRINGS_CDP = "29320"
GLOVERVILLE_CDP = "29410"
GOLDEN_GROVE_CDP = "29635"
GOOSE_CREEK_CITY = "29815"
GOVAN_TOWN = "29950"
GRAMLING_CDP = "30220"
GRANITEVILLE_CDP = "30265"
GRAY_COURT_TOWN = "30355"
GREAT_FALLS_TOWN = "30490"
GREELEYVILLE_TOWN = "30535"
GREEN_SEA_CDP = "30760"
GREENVILLE_CITY = "30850"
GREENWOOD_CITY = "30895"
GREER_CITY = "30985"
GROVER_CDP = "31210"
HAMER_CDP = "31660"
HAMPTON_TOWN = "31885"
HANAHAN_CITY = "32065"
HARBOR_ISLAND_CDP = "32172"
HARDEEVILLE_CITY = "32245"
HARLEYVILLE_TOWN = "32335"
HARTSVILLE_CITY = "32560"
HEATH_SPRINGS_TOWN = "32965"
HELENA_CDP = "33100"
HEMINGWAY_TOWN = "33145"
HICKORY_GROVE_TOWN = "33640"
HILDA_TOWN = "33820"
HILLTOP_CDP = "33977"
HILTON_HEAD_ISLAND_TOWN = "34045"
HODGES_TOWN = "34225"
HOLLY_HILL_TOWN = "34360"
HOLLYWOOD_TOWN = "34495"
HOMELAND_PARK_CDP = "34720"
HOMEWOOD_CDP = "34765"
HONEA_PATH_TOWN = "34810"
HOPKINS_CDP = "34990"
INDIA_HOOK_CDP = "35635"
INMAN_MILLS_CDP = "35800"
INMAN_CITY = "35755"
IRMO_TOWN = "35890"
IRWIN_CDP = "35980"
ISLANDTON_CDP = "36070"
ISLE_OF_PALMS_CITY = "36115"
IVA_TOWN = "36160"
JACKSON_TOWN = "36205"
JACKSONBORO_CDP = "36250"
JAMES_ISLAND_TOWN = "36430"
JAMESTOWN_TOWN = "36475"
JEFFERSON_TOWN = "36610"
JENKINSVILLE_TOWN = "36655"
JOANNA_CDP = "36790"
JOHNSONVILLE_CITY = "37105"
JOHNSTON_TOWN = "37150"
JONESVILLE_TOWN = "37330"
JUDSON_CDP = "37465"
KEOWEE_KEY_CDP = "38058"
KERSHAW_TOWN = "38095"
KETCHUPTOWN_CDP = "38110"
KIAWAH_ISLAND_TOWN = "38162"
KINGSTREE_TOWN = "38590"
KLINE_TOWN = "38950"
LA_FRANCE_CDP = "39265"
LADSON_CDP = "39220"
LAKE_CITY_CITY = "39310"
LAKE_MURRAY_OF_RICHLAND_CDP = "39475"
LAKE_SECESSION_CDP = "39512"
LAKE_VIEW_TOWN = "39715"
LAKE_WYLIE_CDP = "39785"
LAKEWOOD_CDP = "39772"
LAMAR_TOWN = "39805"
LANCASTER_CITY = "39895"
LANDRUM_CITY = "40075"
LANE_TOWN = "40210"
LANGLEY_CDP = "40390"
LATTA_TOWN = "40480"
LAUREL_BAY_CDP = "40525"
LAURENS_CITY = "40615"
LESSLIE_CDP = "41065"
LEXINGTON_TOWN = "41335"
LIBERTY_CITY = "41380"
LINCOLNVILLE_TOWN = "41740"
LITCHFIELD_BEACH_CDP = "41830"
LITTLE_MOUNTAIN_TOWN = "41965"
LITTLE_RIVER_CDP = "42010"
LITTLE_ROCK_CDP = "42055"
LIVE_OAK_CDP = "42095"
LIVINGSTON_TOWN = "42100"
LOBECO_CDP = "42145"
LOCKHART_TOWN = "42190"
LODGE_TOWN = "42280"
LONGCREEK_CDP = "42460"
LORIS_CITY = "42730"
LOWNDESVILLE_TOWN = "42820"
LOWRYS_TOWN = "42865"
LUGOFF_CDP = "43000"
LURAY_TOWN = "43090"
LYDIA_CDP = "43135"
LYMAN_TOWN = "43315"
LYNCHBURG_TOWN = "43360"
MANNING_CITY = "44350"
MANVILLE_CDP = "44395"
MARION_CITY = "44575"
MAULDIN_CITY = "45115"
MAYESVILLE_TOWN = "45295"
MAYO_CDP = "45430"
MCBEE_TOWN = "43495"
MCCLELLANVILLE_TOWN = "43585"
MCCOLL_TOWN = "43630"
MCCONNELLS_TOWN = "43675"
MCCORMICK_TOWN = "43720"
MEGGETT_TOWN = "45790"
MODOC_CDP = "47050"
MONARCH_MILL_CDP = "47200"
MONCKS_CORNER_TOWN = "47275"
MONETTA_TOWN = "47320"
MOUNT_CARMEL_CDP = "48310"
MOUNT_CROGHAN_TOWN = "48355"
MOUNT_PLEASANT_TOWN = "48535"
MOUNTVILLE_CDP = "48670"
MULBERRY_CDP = "48737"
MULLINS_CITY = "48805"
MURPHYS_ESTATES_CDP = "48900"
MURRELLS_INLET_CDP = "48985"
MYRTLE_BEACH_CITY = "49075"
NEESES_TOWN = "49390"
NEW_ELLENTON_TOWN = "49705"
NEWBERRY_CITY = "49570"
NEWPORT_CDP = "49885"
NEWRY_CDP = "49975"
NEWTOWN_CDP = "50020"
NICHOLS_TOWN = "50110"
NINETY_SIX_TOWN = "50290"
NORRIS_TOWN = "50515"
NORTH_AUGUSTA_CITY = "50695"
NORTH_CHARLESTON_CITY = "50875"
NORTH_HARTSVILLE_CDP = "51145"
NORTH_MYRTLE_BEACH_CITY = "51280"
NORTH_SANTEE_CDP = "51367"
NORTH_TOWN = "50560"
NORTHLAKE_CDP = "51180"
NORWAY_TOWN = "51550"
OAK_GROVE_CDP = "51720"
OAKLAND_CDP = "51887"
OLANTA_TOWN = "52540"
OLAR_TOWN = "52585"
OLYMPIA_CDP = "52900"
ORANGEBURG_CITY = "53080"
OSWEGO_CDP = "53485"
PACOLET_TOWN = "53845"
PAGELAND_TOWN = "54025"
PAMPLICO_TOWN = "54340"
PARKER_CDP = "54535"
PARKSVILLE_TOWN = "54700"
PATRICK_TOWN = "54925"
PAULINE_CDP = "54970"
PAWLEYS_ISLAND_TOWN = "55015"
PAXVILLE_TOWN = "55060"
PEAK_TOWN = "55150"
PELION_TOWN = "55420"
PELZER_TOWN = "55465"
PENDLETON_TOWN = "55645"
PERRY_TOWN = "55960"
PICKENS_CITY = "56140"
PIEDMONT_CDP = "56365"
PIMLICO_CDP = "56545"
PINE_RIDGE_CDP = "56905"
PINE_RIDGE_TOWN = "56950"
PINEWOOD_TOWN = "57085"
PINOPOLIS_CDP = "57175"
PLUM_BRANCH_TOWN = "57670"
POMARIA_TOWN = "57850"
PORT_ROYAL_TOWN = "58030"
POWDERSVILLE_CDP = "58170"
PRINCETON_CDP = "58435"
PRIVATEER_CDP = "58570"
PROMISED_LAND_CDP = "58615"
PROSPERITY_TOWN = "58705"
QUINBY_TOWN = "58795"
RAINS_CDP = "58930"
RAVENEL_TOWN = "59020"
RED_BANK_CDP = "59110"
RED_HILL_CDP = "59190"
REEVESVILLE_TOWN = "59380"
REIDVILLE_TOWN = "59425"
REMBERT_CDP = "59470"
RICHBURG_TOWN = "59920"
RIDGE_SPRING_TOWN = "60325"
RIDGELAND_TOWN = "60280"
RIDGEVILLE_TOWN = "60370"
RIDGEWAY_TOWN = "60415"
RIVERVIEW_CDP = "61112"
ROCK_HILL_CITY = "61405"
ROCKVILLE_TOWN = "61495"
ROEBUCK_CDP = "61720"
ROWESVILLE_TOWN = "62035"
RUBY_TOWN = "62080"
RUSSELLVILLE_CDP = "62305"
SALEM_TOWN = "62980"
SALLEY_TOWN = "63115"
SALUDA_TOWN = "63250"
SANDY_SPRINGS_CDP = "63655"
SANGAREE_CDP = "63665"
SANS_SOUCI_CDP = "63700"
SANTEE_TOWN = "63790"
SAXON_CDP = "64240"
SCOTIA_TOWN = "64465"
SCRANTON_TOWN = "64600"
SEABROOK_CDP = "64690"
SEABROOK_ISLAND_TOWN = "64712"
SELLERS_TOWN = "65005"
SENECA_CITY = "65095"
SEVEN_OAKS_CDP = "65207"
SHARON_TOWN = "65410"
SHELDON_CDP = "65590"
SHELL_POINT_CDP = "65680"
SHILOH_CDP = "65950"
SILVERSTREET_TOWN = "66400"
SIMPSONVILLE_CITY = "66580"
SIX_MILE_TOWN = "66760"
SLATER_MARIETTA_CDP = "66917"
SMOAKS_TOWN = "67165"
SMYRNA_TOWN = "67210"
SNELLING_TOWN = "67255"
SOCASTEE_CDP = "67390"
SOCIETY_HILL_TOWN = "67435"
SOUTH_CONGAREE_TOWN = "67705"
SOUTH_SUMTER_CDP = "68177"
SOUTH_UNION_CDP = "68210"
SOUTHERN_SHOPS_CDP = "67750"
SPARTANBURG_CITY = "68290"
SPRINGDALE_CDP = "68380"
SPRINGDALE_TOWN = "68425"
SPRINGFIELD_TOWN = "68470"
ST_ANDREWS_CDP = "62395"
ST_CHARLES_CDP = "62485"
ST_GEORGE_TOWN = "62530"
ST_MATTHEWS_TOWN = "62620"
ST_STEPHEN_TOWN = "62755"
STARR_TOWN = "68875"
STARTEX_CDP = "68920"
STATEBURG_CDP = "69010"
STUCKEY_TOWN = "70045"
SULLIVANS_ISLAND_TOWN = "70090"
SUMMERTON_TOWN = "70225"
SUMMERVILLE_TOWN = "70270"
SUMMIT_TOWN = "70315"
SUMTER_CITY = "70405"
SURFSIDE_BEACH_TOWN = "70585"
SWANSEA_TOWN = "70675"
SYCAMORE_TOWN = "70900"
TAMASSEE_CDP = "71170"
TATUM_TOWN = "71305"
TAYLORS_CDP = "71395"
TEGA_CAY_CITY = "71417"
THE_CLIFFS_VALLEY_CDP = "71658"
TIGERVILLE_CDP = "71890"
TIMMONSVILLE_TOWN = "71980"
TRADESVILLE_CDP = "72295"
TRAVELERS_REST_CITY = "72430"
TRENTON_TOWN = "72520"
TROY_TOWN = "72655"
TURBEVILLE_TOWN = "72745"
ULMER_TOWN = "72880"
UNION_CITY = "73105"
UNITY_CDP = "73240"
UTICA_CDP = "73330"
VALLEY_FALLS_CDP = "73465"
VAN_WYCK_TOWN = "73555"
VANCE_TOWN = "73510"
VARNVILLE_TOWN = "73600"
WADE_HAMPTON_CDP = "73870"
WAGENER_TOWN = "74050"
WALHALLA_CITY = "74095"
WALLACE_CDP = "74140"
WALTERBORO_CITY = "74275"
WARD_TOWN = "74590"
WARE_PLACE_CDP = "74635"
WARE_SHOALS_TOWN = "74680"
WARRENVILLE_CDP = "74725"
WATERLOO_TOWN = "74995"
WATTS_MILLS_CDP = "75220"
WEDGEFIELD_CDP = "75445"
WELCOME_CDP = "75535"
WELLFORD_CITY = "75580"
WEST_COLUMBIA_CITY = "75850"
WEST_PELZER_TOWN = "76345"
WEST_UNION_TOWN = "76435"
WESTMINSTER_CITY = "76165"
WHITE_KNOLL_CDP = "77042"
WHITMIRE_TOWN = "77380"
WHITNEY_CDP = "77425"
WILKINSON_HEIGHTS_CDP = "77672"
WILLIAMS_TOWN = "77785"
WILLIAMSTON_TOWN = "77875"
WILLINGTON_CDP = "77920"
WILLISTON_TOWN = "77965"
WINDSOR_TOWN = "78190"
WINNSBORO_MILLS_CDP = "78505"
WINNSBORO_TOWN = "78460"
WISACKY_CDP = "78640"
WOODFIELD_CDP = "78820"
WOODFORD_TOWN = "78910"
WOODRUFF_CITY = "79090"
WYBOO_CDP = "79341"
YEMASSEE_TOWN = "79450"
YORK_CITY = "79630"
ZION_CDP = "79720"
